==> owncloud-10.0.7.tgz: owncloud/apps/files_external/l10n/sv.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Fel vid hämtning av åtkomst-token. Verifiera att din app-nyckel och hemlighet stämmer.",
    "Step 1 failed. Exception: %s" : "Steg 1 flaerade. Undantag: %s",
    "Step 2 failed. Exception: %s" : "Steg 2 falerade. Undantag: %s",
    "External storage" : "Extern lagring",
    "Personal" : "Personligt",
    "System" : "System",
    "Grant access" : "Bevilja åtkomst",
    "Generate keys" : "Generera nycklar",
    "Error generating key pair" : "Fel vid generering av nyckelpar",
    "All users. Type to select user or group." : "Alla användare. Skriv för att välja användare eller grupp.",
    "(group)" : "(grupp)",
    "Admin defined" : "Admin definerad",
    "Saved" : "Sparad",
    "Empty response from the server" : "Tomt svar från servern",
    "Couldn't get the list of external mount points: {type}" : "Kunde inte hämta listan för externa monteringspunkter: {type}",
    "There was an error with message: " : "Det fanns ett fel med meddelande:",
    "External mount error" : "Fel vid extern montering",
    "Username" : "Användarnamn",
    "Password" : "Lösenord",
    "Credentials saved" : "Sparade referenser",
    "Credentials saving failed" : "Misslyckades med att spara referenser",
    "Credentials required" : "Referenser krävs",
    "Save" : "Spara",
    "Invalid mount point" : "Ogiltig monteringspunkt",
    "Insufficient data: %s" : "Otillräcklig data: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Lagring med id \"%i\" är inte redigerbar av användare",
    "Access key" : "Åtkomstnyckel",
    "Secret key" : "Hemlig nyckel",
    "OAuth1" : "OAuth1",
    "App key" : "App-nyckel",
    "App secret" : "App-hemlighet",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klient ID",
    "Client secret" : "klient secret",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Namn på arrendator",
    "API key" : "API-nyckel",
    "Public key" : "Publik nyckel",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Värdnamn",
    "Port" : "Port",
    "Region" : "Län",
    "Enable SSL" : "Aktivera SSL",
    "Enable Path Style" : "Aktivera Path Style",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Fjärrmapp",
    "Secure https://" : "Säker https://",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "Local" : "Lokal",
    "Location" : "Plats",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "Server",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP-inloggning med hemlig nyckel",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Dela",
    "Domain" : "Domän",
    "SMB / CIFS using OC login" : "SMB / CIFS använder OC inloggning",
    "Username as share" : "Användarnamn till utdelning",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Namn på tjänst",
    "<b>Note:</b> " : "<b> OBS: </ b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b> OBS: </ b> cURL-stöd i PHP inte är aktiverat eller installerat. Montering av %s är inte möjlig. Be din systemadministratör att installera det.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b> OBS: </ b> \"%s\" är inte installerat. Montering av %s är inte möjlig. Be din systemadministratör att installera det.",
    "No external storage configured" : "Ingen extern lagring konfigurerad",
    "Name" : "Namn",
    "Storage type" : "Lagringstyp",
    "Scope" : "Scope",
    "Enable encryption" : "Aktivera kryptering",
    "Enable previews" : "Aktivera förhandsgranskningar",
    "Enable sharing" : "Aktivera delning",
    "Check for changes" : "Sök efter ändringar",
    "Never" : "Aldrig",
    "External Storage" : "Extern lagring",
    "Folder name" : "Mappnamn",
    "Authentication" : "Autentisering",
    "Configuration" : "Konfiguration",
    "Available for" : "Tillgänglig för",
    "Add storage" : "Lägg till lagring",
    "Advanced settings" : "Avancerade inställningar",
    "Delete" : "Radera",
    "Allow users to mount external storage" : "Tillåt användare att montera extern lagring",
    "Allow users to mount the following external storage" : "Tillåt användare att montera följande extern lagring"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/files_external/l10n/sv.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Fel vid hämtning av åtkomst-token. Verifiera att din app-nyckel och hemlighet stämmer.",
    "Step 1 failed. Exception: %s" : "Steg 1 flaerade. Undantag: %s",
    "Step 2 failed. Exception: %s" : "Steg 2 falerade. Undantag: %s",
    "External storage" : "Extern lagring",
    "Personal" : "Personligt",
    "System" : "System",
    "Grant access" : "Bevilja åtkomst",
    "Generate keys" : "Generera nycklar",
    "Error generating key pair" : "Fel vid generering av nyckelpar",
    "All users. Type to select user or group." : "Alla användare. Skriv för att välja användare eller grupp.",
    "(group)" : "(grupp)",
    "Admin defined" : "Admin definerad",
    "Saved" : "Sparad",
    "Empty response from the server" : "Tomt svar från servern",
    "Couldn't get the list of external mount points: {type}" : "Kunde inte hämta listan för externa monteringspunkter: {type}",
    "There was an error with message: " : "Det fanns ett fel med meddelande:",
    "External mount error" : "Fel vid extern montering",
    "Username" : "Användarnamn",
    "Password" : "Lösenord",
    "Credentials saved" : "Sparade referenser",
    "Credentials saving failed" : "Misslyckades med att spara referenser",
    "Credentials required" : "Referenser krävs",
    "Save" : "Spara",
    "Invalid mount point" : "Ogiltig monteringspunkt",
    "Insufficient data: %s" : "Otillräcklig data: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Lagring med id \"%i\" är inte redigerbar av användare",
    "Access key" : "Åtkomstnyckel",
    "Secret key" : "Hemlig nyckel",
    "OAuth1" : "OAuth1",
    "App key" : "App-nyckel",
    "App secret" : "App-hemlighet",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klient ID",
    "Client secret" : "klient secret",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Namn på arrendator",
    "API key" : "API-nyckel",
    "Public key" : "Publik nyckel",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Värdnamn",
    "Port" : "Port",
    "Region" : "Län",
    "Enable SSL" : "Aktivera SSL",
    "Enable Path Style" : "Aktivera Path Style",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Fjärrmapp",
    "Secure https://" : "Säker https://",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "Local" : "Lokal",
    "Location" : "Plats",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "Server",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP-inloggning med hemlig nyckel",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Dela",
    "Domain" : "Domän",
    "SMB / CIFS using OC login" : "SMB / CIFS använder OC inloggning",
    "Username as share" : "Användarnamn till utdelning",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Namn på tjänst",
    "<b>Note:</b> " : "<b> OBS: </ b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b> OBS: </ b> cURL-stöd i PHP inte är aktiverat eller installerat. Montering av %s är inte möjlig. Be din systemadministratör att installera det.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b> OBS: </ b> \"%s\" är inte installerat. Montering av %s är inte möjlig. Be din systemadministratör att installera det.",
    "No external storage configured" : "Ingen extern lagring konfigurerad",
    "Name" : "Namn",
    "Storage type" : "Lagringstyp",
    "Scope" : "Scope",
    "Enable encryption" : "Aktivera kryptering",
    "Enable previews" : "Aktivera förhandsgranskningar",
    "Enable sharing" : "Aktivera delning",
    "Check for changes" : "Sök efter ändringar",
    "Never" : "Aldrig",
    "External Storage" : "Extern lagring",
    "Folder name" : "Mappnamn",
    "Authentication" : "Autentisering",
    "Configuration" : "Konfiguration",
    "Available for" : "Tillgänglig för",
    "Add storage" : "Lägg till lagring",
    "Advanced settings" : "Avancerade inställningar",
    "Delete" : "Radera",
    "Allow users to mount external storage" : "Tillåt användare att montera extern lagring",
    "Allow users to mount the following external storage" : "Tillåt användare att montera följande extern lagring",
    "No URL provided by backend " : "Ingen URL tillhandahölls av gränssnitt",
    "Disable external storage" : "Avaktivera extern lagring",
    "Error configuring OAuth1" : "Kunde inte konfigurera OAuth1",
    "Please provide a valid app key and secret." : "Ange en giltig appnyckel och hemlis.",
    "Disabling external storage will unmount all storages for all users, are you sure ?" : "Att ta bort stöd för extern lagring kommer att avmontera all lagring för alla användare, vill du fortsätta?",
    "Compatibility with Mac NFD encoding (slow)" : "Kompativilitet med MAC NFD-omkodning (långsamt)"
},
"nplurals=2; plural=(n != 1);");
